
.. _algorithms/cuts:

Cuts
****

Algorithms
----------

.. automodule:: jgrapht.algorithms.cuts
   :members:

Types
-----

Cuts are represented using instances of the following classes.

.. autoclass:: jgrapht.types.Cut
   :members:

.. autoclass:: jgrapht.types.GomoryHuTree
   :members:


